paper

package module
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2021 License: ISC Imports: 2 Imported by: 0

README

Paper

Paper is a tiny web framework that I created to learn Go A lot of things are were just used to test functionalities

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRouter

func NewRouter() *router.Router

Types

type Context

type Context = context.Context

type HandlerFunc added in v0.0.3

type HandlerFunc = context.HandlerFunc

type Middleware

type Middleware = router.Middleware

type Router

type Router = router.Router

Directories

Path Synopsis
_examples
hello command
pathVariable command

Jump to